[![DOI](http://joss.theoj.org/papers/10.21105/joss.00638/status.svg)](https://doi.org/10.21105/joss.00638)
[![Build Status](https://travis-ci.org/jaisenbe58r/mlearner.svg?branch=master)](https://travis-ci.org/jaisenbe58r/mlearner)
[![Build status](https://ci.appveyor.com/api/projects/status/7vx20e0h5dxcyla2/branch/master?svg=true)](https://ci.appveyor.com/project/jaisenbe58r/mlearner/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/2a199e28871c477d9ecf6e200b4977b9)](https://www.codacy.com/manual/jaisenbe58r/mlearner?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jaisenbe58r/mlearner&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/jaisenbe58r/mlearner/badge.svg?branch=master&service=github)](https://coveralls.io/github/jaisenbe58r/mlearner?branch=master)
![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)
![Python 3.7](https://img.shields.io/badge/python-3.7-blue.svg)
![Python 3.7](https://img.shields.io/badge/python-3.8-blue.svg)
![License](https://img.shields.io/badge/license-MIT-ORANGE.svg)
[![Discuss](https://img.shields.io/badge/discuss-DISCORD-PURPLE.svg)](https://discord.gg/yHCCa2)

![](./docs/sources/img/logo.png)


**mlearner (machine learning for data enginnering) is a Python library of useful tools for the day-to-day data science tasks.**

<br>

Jaime Sendra - 2020

<br>

## Links

- **Documentation:** [http://jaisenbe58r.github.io/mlearner](http://jaisenbe58r.github.io/mlearner)
- PyPI: [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner)
- Changelog: [http://jaisenbe58r.github.io/mlearner/CHANGELOG](http://jaisenbe58r.github.io/mlearner/CHANGELOG)
- Contributing: [http://jaisenbe58r.github.io/mlearner/CONTRIBUTING](http://jaisenbe58r.github.io/mlearner/CONTRIBUTING)
- Questions? Check out the [Google Groups mailing list](https://groups.google.com/forum/#!forum/mlearner)

<br>
<br>

## Installing mlearner

#### PyPI

To install mlearner, just execute  

```bash
pip install mlearner  
```

Alternatively, you could download the package manually from the Python Package Index [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner), unzip it, navigate into the package, and use the command:

```bash
python setup.py install
```

#### Conda
If you use conda, to install mlearner just execute

```bash
conda install -c conda-forge mlearner 
```

#### Dev Version

The mlearner version on PyPI may always be one step behind; you can install the latest development version from the GitHub repository by executing

```bash
pip install git+git://github.com/jaisenbe58r/mlearner.git#egg=mlearner
```

Or, you can fork the GitHub repository from https://github.com/jaisenbe58r/mlearnerer and install mlearner from your local drive via

```bash
python setup.py install
```


---

## License


## Contact

